@@ -35,7 +35,7 @@ from .crypto.low_level import blake2b_128
 from .archiver import Archiver
 from .archive import Archive, get_item_uid_gid
 from .hashindex import FuseVersionsIndex
-from .helpers import daemonize, daemonizing, hardlinkable, signal_handler, format_file_size
+from .helpers import daemonize, daemonizing, hardlinkable, signal_handler, format_file_size, Error
 from .helpers import msgpack
 from .item import Item
 from .lrucache import LRUCache
@@ -234,7 +234,7 @@ class ItemCache:
         self.write_offset = write_offset
 
 
-class FuseBackend(object):
+class FuseBackend:
     """Virtual filesystem based on archive(s) to provide information to fuse
     """
 
@@ -272,6 +272,9 @@ class FuseBackend(object):
     def _create_filesystem(self):
         self._create_dir(parent=1)  # first call, create root dir (inode == 1)
         if self._args.location.archive:
+            if self.versions:
+                raise Error("for versions view, do not specify a single archive, "
+                            "but always give the repository as location.")
             self._process_archive(self._args.location.archive)
         else:
             self.versions_index = FuseVersionsIndex()
